@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '1.047_003';
+our $VERSION = '1.049_001';
 
 =head1 NAME
 
@@ -35,6 +35,7 @@ use File::Temp qw( tempfile );
 use Module::ScanDeps ();
 use PAR ();
 use PAR::Filter ();
+use PAR::Filter::PodStrip ();
 
 use constant OPTIONS => {
     'a|addfile:s@'   => 'Additional files to pack',
@@ -821,8 +822,8 @@ sub pack_manifest_hash {
     # generate a selective set of filters from the options passed in via -F
     my $mod_filter = _generate_filter($opt, 'F');
 
-    (my $privlib = $Config{privlib}) =~ s{\\}{/}g;
-    (my $archlib = $Config{archlib}) =~ s{\\}{/}g;
+    my ($privlib, $archlib) = map { _maybe_relocate($_) } @Config{qw(privlib archlib)};
+
     foreach my $pfile (sort grep length $map{$_}, keys %map) {
         next if !$opt->{B} and (
             ($map{$pfile} eq "$privlib/$pfile") or
@@ -938,6 +939,18 @@ sub pack_manifest_hash {
 }
 
 
+sub _maybe_relocate {
+    my ($lib) = @_;
+
+    if ($Config{userelocatableinc})
+    {
+        $lib =~ s/^\.\.\./dirname($^X)/e;
+        $lib = abs_path($lib);
+    }
+    $lib =~ s{\\}{/}g;
+    return $lib;
+}
+
 sub _generate_filter {
     my $opt = shift; # options hash
     my $key = shift; # F or f? modules or script?
@@ -957,7 +970,6 @@ sub _generate_filter {
             filter => PAR::Filter->new($filter)
         };
     }
-    my $podstrip = PAR::Filter->new('PodStrip');
 
     my $filtersub = sub {
         my $ref = shift;
@@ -975,7 +987,7 @@ sub _generate_filter {
 
         # PodStrip by default, overridden by -F or $ENV{PAR_VERBATIM}
         if ($filtered == 1 and not $verbatim) {
-            $ref = $podstrip->apply($ref, $name);
+            $ref = PAR::Filter::PodStrip->apply($ref, '');
         }
         return $ref;
     };
